.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_auto_examples_segmentation_plot_rag_draw.py>`     to download the full example code or to run this example in your browser via Binder
    .. rst-class:: sphx-glr-example-title

    .. _sphx_glr_auto_examples_segmentation_plot_rag_draw.py:


======================================
Drawing Region Adjacency Graphs (RAGs)
======================================

This example constructs a Region Adjacency Graph (RAG) and draws it with
the `rag_draw` method.



.. image:: /auto_examples/segmentation/images/sphx_glr_plot_rag_draw_001.png
    :class: sphx-glr-single-img






.. code-block:: default


    from skimage import data, segmentation
    from skimage.future import graph
    from matplotlib import pyplot as plt


    img = data.coffee()
    labels = segmentation.slic(img, compactness=30, n_segments=400, start_label=1)
    g = graph.rag_mean_color(img, labels)

    fig, ax = plt.subplots(nrows=2, sharex=True, sharey=True, figsize=(6, 8))

    ax[0].set_title('RAG drawn with default settings')
    lc = graph.show_rag(labels, g, img, ax=ax[0])
    # specify the fraction of the plot area that will be used to draw the colorbar
    fig.colorbar(lc, fraction=0.03, ax=ax[0])

    ax[1].set_title('RAG drawn with grayscale image and viridis colormap')
    lc = graph.show_rag(labels, g, img,
                        img_cmap='gray', edge_cmap='viridis', ax=ax[1])
    fig.colorbar(lc, fraction=0.03, ax=ax[1])

    for a in ax:
        a.axis('off')

    plt.tight_layout()
    plt.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  1.882 seconds)


.. _sphx_glr_download_auto_examples_segmentation_plot_rag_draw.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example


  .. container:: binder-badge

    .. image:: https://mybinder.org/badge_logo.svg
      :target: https://mybinder.org/v2/gh/scikit-image/scikit-image/v0.17.x?filepath=notebooks/auto_examples/segmentation/plot_rag_draw.ipynb
      :width: 150 px


  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_rag_draw.py <plot_rag_draw.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_rag_draw.ipynb <plot_rag_draw.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
